@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.4.4"
+    version = "1.4.7"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -65,17 +65,6 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
                     project, "custom_keyword", "DINGTALK_CUSTOM_KEYWORD"
                 ),
             },
-            {
-                "name": "warning_counts",
-                "label": "告警次数",
-                "type": "string",
-                "placeholder": "事件告警次数",
-                "required": False,
-                "help": "事件告警次数达到阀值，推送告警信息。",
-                "default": self.set_default(
-                    project, "warning_counts", "DINGTALK_WARNING_COUNTS"
-                ),
-            },
             {
                 "name": "phones",
                 "label": "通知人员",
@@ -125,9 +114,9 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
 
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
-        payload = f"{payload} > status: {group.status} \n\n"
-        payload = f"{payload} > 告警次数: {group.times_seen} \n\n"
-        payload = f"{payload} > 查看详情: <font color=blue>[{group.title}]({issue_link})</font> \n\n"
+        # payload = f"{payload} > status: {group.status} \n\n"
+        payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
+        payload = f"{payload} > 查看详情: <font color=blue>[{group.title if group.title else 'unknown'}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
 
         headers = {
